==> foop_loyalty_plugin-0.7.1.tar.gz: lib/utils/localization.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:shared_preferences/shared_preferences.dart';

class AppLocalizations {
  final Locale locale;
  String? languageCode;
  SharedPreferences? prefs;
  AppLocalizations(this.locale);

  // Helper method to keep the code in the widgets concise
  // Localizations are accessed using an InheritedWidget "of" syntax
  static AppLocalizations? of(BuildContext context) {
    return Localizations.of<AppLocalizations>(context, AppLocalizations);
  }

  late Map<String, String> _localizedStrings;

  Future<bool> load() async {
    prefs = await SharedPreferences.getInstance();
    String jsonString = await rootBundle.loadString(
        'packages/foop_loyalty_plugin/assets/lang/${prefs!.getString("app_language_code") ?? "en"}.json');
    Map<String, dynamic> jsonMap = json.decode(jsonString);

    _localizedStrings = jsonMap.map((key, value) {
      return MapEntry(key, value.toString());
    });

    return true;
  }

  Future<String> getData() async {
    // Load the language JSON file from the "lang" folder
    String jsonString = await rootBundle
        .loadString('packages/foop_loyalty_plugin/assets/lang/${locale.languageCode}.json');
    // Map<String, dynamic> jsonMap = json.decode(jsonString);

    return jsonString;
  }

  static const LocalizationsDelegate<AppLocalizations> delegate =
  _AppLocalizationsDelegate();

  String translate(String key, {Map<String, String?>? arguments}) {
    String translation = _localizedStrings[key] ?? '';
    if (arguments == null || arguments.length == 0) {
      return translation;
    }
    arguments.forEach((argumentKey, value) {
      if (value == null) {
        print(
            'Value for "$argumentKey" is null in call of translate(\'$key\')');
        value = '';
      }
      translation = translation.replaceAll("\$$argumentKey", value);
    });
    return translation;
  }

// This method will be called from every widget which needs a localized text
// String translate(String key) {
//   return _localizedStrings[key];
// }
}

// LocalizationsDelegate is a factory for a set of localized resources
// In this case, the localized strings will be gotten in an AppLocalizations object
class _AppLocalizationsDelegate
    extends LocalizationsDelegate<AppLocalizations> {
  // This delegate instance will never change (it doesn't even have fields!)
  // It can provide a constant constructor.
  const _AppLocalizationsDelegate();

  @override
  bool isSupported(Locale locale) {
    // Include all of your supported language codes here
    return ['en', 'hi', 'ta', 'te', 'ur'].contains(locale.languageCode);
  }

  @override
  Future<AppLocalizations> load(Locale locale) async {
    // AppLocalizations class is where the JSON loading actually runs
    AppLocalizations localizations = new AppLocalizations(locale);
    await localizations.load();
    return localizations;
  }

  @override
  bool shouldReload(_AppLocalizationsDelegate old) => false;
}

==> foop_loyalty_plugin-0.11.1.tar.gz: lib/utils/localization.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import 'basicInfo.dart';

class AppLocalizationsRewards {
  final Locale locale;
  String? languageCode;
  BasicInfo? basicInfo = BasicInfo();
  AppLocalizationsRewards(this.locale);

  // Helper method to keep the code in the widgets concise
  // Localizations are accessed using an InheritedWidget "of" syntax
  static AppLocalizationsRewards? of(BuildContext context) {
    return Localizations.of<AppLocalizationsRewards>(context, AppLocalizationsRewards);
  }

  late Map<String, String> _localizedStrings;

  Future<bool> load() async {

    String jsonString = await rootBundle.loadString(
        'packages/foop_loyalty_plugin/assets/lang/${locale.languageCode}.json');
    Map<String, dynamic> jsonMap = json.decode(jsonString);

    _localizedStrings = jsonMap.map((key, value) {
      return MapEntry(key, value.toString());
    });

    return true;
  }

  Future<String> getData() async {
    // Load the language JSON file from the "lang" folder
    String jsonString = await rootBundle
        .loadString('packages/foop_loyalty_plugin/assets/lang/${locale.languageCode}.json');
    // Map<String, dynamic> jsonMap = json.decode(jsonString);

    return jsonString;
  }

  static const LocalizationsDelegate<AppLocalizationsRewards> delegate =
  _AppLocalizationsDelegate();

  String translate(String key, {Map<String, String?>? arguments}) {
    String translation = _localizedStrings[key] ?? '';
    if (arguments == null || arguments.length == 0) {
      return translation;
    }
    arguments.forEach((argumentKey, value) {
      if (value == null) {
        print(
            'Value for "$argumentKey" is null in call of translate(\'$key\')');
        value = '';
      }
      translation = translation.replaceAll("\$$argumentKey", value);
    });
    return translation;
  }

// This method will be called from every widget which needs a localized text
// String translate(String key) {
//   return _localizedStrings[key];
// }
}

// LocalizationsDelegate is a factory for a set of localized resources
// In this case, the localized strings will be gotten in an AppLocalizations object
class _AppLocalizationsDelegate
    extends LocalizationsDelegate<AppLocalizationsRewards> {
  // This delegate instance will never change (it doesn't even have fields!)
  // It can provide a constant constructor.
  const _AppLocalizationsDelegate();

  @override
  bool isSupported(Locale locale) {
    // Include all of your supported language codes here
    return ['en', 'hi', 'ta', 'te', 'ur'].contains(locale.languageCode);
  }

  @override
  Future<AppLocalizationsRewards> load(Locale locale) async {
    // AppLocalizations class is where the JSON loading actually runs
    AppLocalizationsRewards localizations = new AppLocalizationsRewards(locale);
    await localizations.load();
    return localizations;
  }

  @override
  bool shouldReload(_AppLocalizationsDelegate old) => false;
}
